@@ -299,6 +299,11 @@ class Interval:
         Return the non-translated interval quality.
         """
         return self._nn_to_interval_quality[self.get_quality_short()]
+    def get_cname_short(self):
+        """
+        Return the short untranslated interval name, like p5 or M2
+        """
+        return "%s%i" % (self.get_quality_short(), self.steps())
     def get_cname(self):
         """
         Return the full untranslated interval name, both the number and quality.
