@@ -51,8 +51,7 @@ class MusicDisplayer(gtk.ScrolledWindow):
     def display_range(self, music, fontsize, start, end):
         """Exception handling should be done by the caller."""
         #FIXME this function only handles music where start == Rat(0, 1) correctly
-        if start != Rat(0, 1):
-            print "warning: musicdisplayer.display_range: start != Rat(0, 1)"
+        assert start == Rat(0, 1)
         score = parser.parse_to_score_object(music)
         tv = score.m_timeposdict.keys()
         v = [t for t in tv if t < end]
