@@ -213,10 +213,18 @@ def check_file(filename):
         # Check mapping key
         v1 = find_string_formatting_mapping_keys(entry.get_msgid())
         v2 = find_string_formatting_mapping_keys(entry.get_msgstr())
+        all_1 = v1 and bool([x for x in v1 if x[0] is not None])
+        all_2 = v2 and bool([x for x in v2 if x[0] is not None])
+        v1x = list(v1)
+        v2x = list(v2)
+        v1x.sort()
+        v2x.sort()
+        format_ok = (v1x == v2x and all_1 and all_2)
         if (v1 != v2) and entry.get_msgstr() \
                 and (entry.get_status() not in ('obsolete', 'fuzzy')) \
                 and not [s for s in entry.m_comment if 'no-python-format' in s] \
-                and (entry.get_msgid() not in ok_different_mapping_key):
+                and (entry.get_msgid() not in ok_different_mapping_key) \
+                and (not format_ok):
             file_ok = False
             print "Mapping key not equal in the file", filename
             print "\tmsgid: \"" + entry.get_msgid() + "\""
